@@ -23,10 +23,12 @@ replace the version strings in modules.
 
 Someday I may make a Dist::Zilla plugin out of this.
 
-=head1 SYNAPSIS
+=head1 SYNOPSIS
 
 ./buildpod.pl
 
+./buildpod.pl fixfooter
+
 =cut
 
 
@@ -52,15 +54,11 @@ use Data::Printer;
 
 =pod
 
-=head1 buildpod.pl
-
-=head1 SYNOPSIS
-
-=head1 VERSION 2019.0902
+=head1 VERSION 2021.0422
 
 =cut
 
-our $VERSION='2019.0902';
+our $VERSION='2021.0422';
 
 my $m2p = Markdown::Pod->new;
 
@@ -117,61 +115,85 @@ John Karr (BRAINBUZ) brainbuz@cpan.org
 
 CONTRIBUTORS
 
-Copyright 2019-2020 by John Karr (BRAINBUZ) brainbuz@cpan.org.
+Copyright 2019-2021 by John Karr (BRAINBUZ) brainbuz@cpan.org.
 
 LICENSE
 
 This module is released under the GNU Public License Version 3. See license file for details. For more information on this license visit L<http://fsf.org>.
 
+SUPPORT
+
+This software is provided as is, per the terms of the GNU Public License. Professional Support, Validation and Customization services are available, please contact the Author for a quote.
+
 =cut
 
 FOOTER
 
+my $fixfooter = 0;
+for (@ARGV) {
+  $fixfooter = 1 if $_ eq 'fixfooter';
+}
+
 my $dist = path( './dist.ini')->slurp;
 $dist =~ /version\s? =\s?(\d+\.\d+)/;
 my $version = $1;
 
-my @mdfiles = path("./md")->children( qr/md$/ );
+# my @mdfiles = path(".")->children( qr/md$/ );
+
 my @pmfiles1 = path("./lib/Vote/Count")->children( qr/pm$|pod$/);
 my @pmfiles2 = path("./lib/Vote/Count/Method")->children( qr/pm$/);
+my @pmfiles3 = path("./lib/Vote/Count/Charge")->children( qr/pm$/);
+my @pmfiles4 = path("./lib/Vote/Count/Helper")->children( qr/pm$/);
 my $countpm = path( "./lib/Vote/Count.pm");
-my @pmfiles = ( @pmfiles1, @pmfiles2, $countpm);
+my @pmfiles = ( @pmfiles1, @pmfiles2, @pmfiles3, @pmfiles4,$countpm);
 my %pmkeys = ();
 for my $pm (@pmfiles ) {
   $pm =~ /(.*)\.(pm$|pod$)/; # extract the part of the string before .pm
   my @bits = split /\//, $1; # split extracted on /, llast bit is basename
   $pmkeys{ $bits[-1] } = $pm ; # put the path object in the hash keyed on the basename.
 }
-FORMD:
-for my $md ( @mdfiles ) {
-  my $name = $md->basename;
-  $name =~ s/\.md$//;
-  say "base name $name";
-  if ( $pmkeys{ $name }) {
-    my $pm = delete $pmkeys{ $name }; # remove from keys, so we dont repeat it later.
-    my $mdtext = path($md)->slurp();
-    my $pmtext = path($pm)->slurp();
-    $pmtext = add_pod( $pmtext, $mdtext );
-    $pmtext = fix_version( $pmtext, $version);
-    $pm->spew( $pmtext );
-    say "updated $pm added pod from $md";
-  } else {
-      next FORMD if $md =~ /README/ ;
-      my $mdtext = path($md)->slurp();
-      $mdtext =~ s/(\# ABSTRACT.*)\n//;
-      my $abstract = $1;
-      my $pod =  $m2p->markdown_to_pod( markdown => $mdtext );
-      my $versionline = "=head1 VERSION $version";
-warn $versionline;
-      # $pod = "$abstract\n$versionline\n$pod\n$footer";
-      $pod = "$abstract\n\n=pod\n\n$versionline\n$pod\n$footer\n=cut\n";
-      path( "./lib/Vote/$name.pod")->spew($pod);
-  }
+# FORMD:
+# for my $md ( @mdfiles ) {
+#   my $name = $md->basename;
+# say "ORI base name $name";
+#   $name =~ s/\.md$//;
+#   say "base name $name";
+#   if ( $pmkeys{ $name }) {
+#     my $pm = delete $pmkeys{ $name }; # remove from keys, so we dont repeat it later.
+#     my $mdtext = path($md)->slurp();
+#     my $pmtext = path($pm)->slurp();
+#     $pmtext = add_pod( $pmtext, $mdtext );
+#     $pmtext = fix_version( $pmtext, $version);
+#     $pm->spew( $pmtext );
+#     say "updated $pm added pod from $md";
+#   } else {
+#       next FORMD if $md =~ /README/ ;
+#       my $mdtext = try { path($md)->slurp(); }
+#         catch { warn "failed to slurp $md"};
+#       $mdtext =~ s/(\# ABSTRACT.*)\n//;
+#       my $abstract = $1;
+#       my $pod =  $m2p->markdown_to_pod( markdown => $mdtext );
+#       my $versionline = "=head1 VERSION $version";
+# warn $versionline;
+#       # $pod = "$abstract\n$versionline\n$pod\n$footer";
+#       $pod = "$abstract\n\n=pod\n\n$versionline\n$pod\n$footer\n=cut\n";
+#       path( "./lib/Vote/$name.pod")->spew($pod);
+#   }
+
+# }
+
   for my $pm ( values %pmkeys ) {
 warn "fixing $pm"    ;
     my $pmtext = path($pm)->slurp;
     unless ($pmtext =~ /\#FOOTER/) { $pmtext .= $footer ; }
+    elsif ( $fixfooter ) {
+      say "updateding footer $pm"      ;
+      # $pmtext =~ s/(?s)\#FOOTER.*/$footer/;
+      my $splitstr = "#FOOTER\n";
+      my ($body, @trim) = split /$splitstr/, $pmtext;
+      $body =~ s/\n+$/\n/g;
+      $pmtext = $body . $footer;
+    }
     path($pm)->spew( fix_version( $pmtext, $version) );
     say "updated version in $pm";
-  }
-}
+  }
\ No newline at end of file
