@@ -13,7 +13,6 @@ use Data::Dumper;
 use Time::Piece;
 use Path::Tiny;
 use Vote::Count::Matrix;
-use Vote::Count::ReadBallots qw( read_ballots read_range_ballots);
 # use Storable 3.15 'dclone';
 
 no warnings 'experimental';
@@ -26,6 +25,24 @@ Vote::Count
 
 =head1 VERSION 1.21
 
+=head2 A Toolkit for determining the outcome of Preferential Ballots.
+
+Provides a Toolkit for implementing multiple voting systems, allowing a wide range of method options. Vote::Count provides a lot of options to facilitate writing code to match your election rules.
+
+=head1 DOCUMENTATION
+
+=head2 L<OVERVIEW|Overview>
+
+An overview of Preferential Voting and introduction to Vote::Count
+
+=head2 L<CATALOG|Catalog>
+
+Catalog of Preferential Voting Methods implemented by Vote::Count and the Modules providing them.
+
+=head2 L<MULTIMEMBER|MultiMember>
+
+Overview of Preferential Ballots for Multi-Member Elections and their implementation in Vote::Count.
+
 =cut
 
 # ABSTRACT: Parent Module for Vote::Count. Toolkit for vote counting.
